#[non_exhaustive]pub enum DetectIntentResponseView {
Unspecified,
Full,
Basic,
Default,
UnknownValue(UnknownValue),
}Available on crate feature
sessions only.Expand description
The response view specifies which fields in the QueryResult to return.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Not specified. DETECT_INTENT_RESPONSE_VIEW_DEFAULT will be used.
Full
Full response view includes all fields.
Basic
Basic response view omits the following fields:
Default
Default response view omits the following fields:
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DetectIntentResponseView::value or DetectIntentResponseView::name.
Implementations