#[non_exhaustive]pub struct EventHandler {
pub event: String,
pub condition: String,
pub fulfillment: Option<Fulfillment>,
/* private fields */
}Available on crate feature
playbooks only.Expand description
A handler that is triggered by the specified event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event: StringRequired. The name of the event that triggers this handler.
condition: StringOptional. The condition that must be satisfied to trigger this handler.
fulfillment: Option<Fulfillment>Required. The fulfillment to call when the event occurs.
Implementations
Sourceimpl EventHandler
impl EventHandler
Sourcepub fn set_condition<T: Into<String>>(self, v: T) -> Self
pub fn set_condition<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_fulfillment<T>(self, v: T) -> Selfwhere
T: Into<Fulfillment>,
pub fn set_fulfillment<T>(self, v: T) -> Selfwhere
T: Into<Fulfillment>,
Sets the value of fulfillment.
Example
ⓘ
use google_cloud_dialogflow_cx_v3::model::Fulfillment;
let x = EventHandler::new().set_fulfillment(Fulfillment::default()/* use setters */);Sourcepub fn set_or_clear_fulfillment<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fulfillment>,
pub fn set_or_clear_fulfillment<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fulfillment>,
Sets or clears the value of fulfillment.
Example
ⓘ
use google_cloud_dialogflow_cx_v3::model::Fulfillment;
let x = EventHandler::new().set_or_clear_fulfillment(Some(Fulfillment::default()/* use setters */));
let x = EventHandler::new().set_or_clear_fulfillment(None::<Fulfillment>);Trait Implementations
Sourceimpl Clone for EventHandler
impl Clone for EventHandler
Sourcefn clone(&self) -> EventHandler
fn clone(&self) -> EventHandler
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventHandler
impl Debug for EventHandler
Sourceimpl Default for EventHandler
impl Default for EventHandler
Sourcefn default() -> EventHandler
fn default() -> EventHandler
Returns the “default value” for a type. Read more
Sourceimpl Message for EventHandler
impl Message for EventHandler
Sourceimpl PartialEq for EventHandler
impl PartialEq for EventHandler
Sourcefn eq(&self, other: &EventHandler) -> bool
fn eq(&self, other: &EventHandler) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EventHandler