#[non_exhaustive]pub struct CreateFlowRequest {
pub parent: String,
pub flow: Option<Flow>,
pub language_code: String,
/* private fields */
}Available on crate feature
flows only.Expand description
The request message for Flows.CreateFlow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The agent to create a flow for.
Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.
flow: Option<Flow>Required. The flow to create.
language_code: StringThe language of the following fields in flow:
Flow.event_handlers.trigger_fulfillment.messagesFlow.event_handlers.trigger_fulfillment.conditional_casesFlow.transition_routes.trigger_fulfillment.messagesFlow.transition_routes.trigger_fulfillment.conditional_cases
If not specified, the agent’s default language is used. Many languages are supported. Note: languages must be enabled in the agent before they can be used.
Implementations
Sourceimpl CreateFlowRequest
impl CreateFlowRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_flow<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_flow<T>(self, v: Option<T>) -> Self
Sourcepub fn set_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of language_code.
Example
ⓘ
let x = CreateFlowRequest::new().set_language_code("example");Trait Implementations
Sourceimpl Clone for CreateFlowRequest
impl Clone for CreateFlowRequest
Sourcefn clone(&self) -> CreateFlowRequest
fn clone(&self) -> CreateFlowRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateFlowRequest
impl Debug for CreateFlowRequest
Sourceimpl Default for CreateFlowRequest
impl Default for CreateFlowRequest
Sourcefn default() -> CreateFlowRequest
fn default() -> CreateFlowRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateFlowRequest
impl Message for CreateFlowRequest
Sourceimpl PartialEq for CreateFlowRequest
impl PartialEq for CreateFlowRequest
Sourcefn eq(&self, other: &CreateFlowRequest) -> bool
fn eq(&self, other: &CreateFlowRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateFlowRequest