#[non_exhaustive]pub struct CreateTransitionRouteGroupRequest {
pub parent: String,
pub transition_route_group: Option<TransitionRouteGroup>,
pub language_code: String,
/* private fields */
}transition-route-groups only.Expand description
The request message for TransitionRouteGroups.CreateTransitionRouteGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The flow to create an
TransitionRouteGroup
for. Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>
or projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>
for agent-level groups.
transition_route_group: Option<TransitionRouteGroup>Required. The transition route group to create.
language_code: StringThe language of the following fields in TransitionRouteGroup:
TransitionRouteGroup.transition_routes.trigger_fulfillment.messages
TransitionRouteGroup.transition_routes.trigger_fulfillment.conditional_cases
If not specified, the agent’s default language is used. Many languages are supported. Note: languages must be enabled in the agent before they can be used.
Implementations
Sourceimpl CreateTransitionRouteGroupRequest
impl CreateTransitionRouteGroupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_transition_route_group<T>(self, v: T) -> Selfwhere
T: Into<TransitionRouteGroup>,
pub fn set_transition_route_group<T>(self, v: T) -> Selfwhere
T: Into<TransitionRouteGroup>,
Sets the value of transition_route_group.
Example
use google_cloud_dialogflow_cx_v3::model::TransitionRouteGroup;
let x = CreateTransitionRouteGroupRequest::new().set_transition_route_group(TransitionRouteGroup::default()/* use setters */);Sourcepub fn set_or_clear_transition_route_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransitionRouteGroup>,
pub fn set_or_clear_transition_route_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransitionRouteGroup>,
Sets or clears the value of transition_route_group.
Example
use google_cloud_dialogflow_cx_v3::model::TransitionRouteGroup;
let x = CreateTransitionRouteGroupRequest::new().set_or_clear_transition_route_group(Some(TransitionRouteGroup::default()/* use setters */));
let x = CreateTransitionRouteGroupRequest::new().set_or_clear_transition_route_group(None::<TransitionRouteGroup>);Sourcepub fn set_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of language_code.
Example
let x = CreateTransitionRouteGroupRequest::new().set_language_code("example");Trait Implementations
Sourceimpl Clone for CreateTransitionRouteGroupRequest
impl Clone for CreateTransitionRouteGroupRequest
Sourcefn clone(&self) -> CreateTransitionRouteGroupRequest
fn clone(&self) -> CreateTransitionRouteGroupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateTransitionRouteGroupRequest
impl Default for CreateTransitionRouteGroupRequest
Sourcefn default() -> CreateTransitionRouteGroupRequest
fn default() -> CreateTransitionRouteGroupRequest
Sourceimpl PartialEq for CreateTransitionRouteGroupRequest
impl PartialEq for CreateTransitionRouteGroupRequest
Sourcefn eq(&self, other: &CreateTransitionRouteGroupRequest) -> bool
fn eq(&self, other: &CreateTransitionRouteGroupRequest) -> bool
self and other values to be equal, and is used by ==.