#[non_exhaustive]pub struct DataStoreConnection {
pub data_store_type: DataStoreType,
pub data_store: String,
pub document_processing_mode: DocumentProcessingMode,
/* private fields */
}Available on crate features
flows or pages or sessions or test-cases or tools only.Expand description
A data store connection. It represents a data store in Discovery Engine and the type of the contents it contains.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_store_type: DataStoreTypeThe type of the connected data store.
data_store: StringThe full name of the referenced data store.
Formats:
projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}
projects/{project}/locations/{location}/dataStores/{data_store}
document_processing_mode: DocumentProcessingModeThe document processing mode for the data store connection. Should only be set for PUBLIC_WEB and UNSTRUCTURED data stores. If not set it is considered as DOCUMENTS, as this is the legacy mode.
Implementations
Sourceimpl DataStoreConnection
impl DataStoreConnection
Sourcepub fn set_data_store_type<T: Into<DataStoreType>>(self, v: T) -> Self
pub fn set_data_store_type<T: Into<DataStoreType>>(self, v: T) -> Self
Sets the value of data_store_type.
Example
ⓘ
use google_cloud_dialogflow_cx_v3::model::DataStoreType;
let x0 = DataStoreConnection::new().set_data_store_type(DataStoreType::PublicWeb);
let x1 = DataStoreConnection::new().set_data_store_type(DataStoreType::Unstructured);
let x2 = DataStoreConnection::new().set_data_store_type(DataStoreType::Structured);Sourcepub fn set_data_store<T: Into<String>>(self, v: T) -> Self
pub fn set_data_store<T: Into<String>>(self, v: T) -> Self
Sets the value of data_store.
Example
ⓘ
let x = DataStoreConnection::new().set_data_store("example");Sourcepub fn set_document_processing_mode<T: Into<DocumentProcessingMode>>(
self,
v: T,
) -> Self
pub fn set_document_processing_mode<T: Into<DocumentProcessingMode>>( self, v: T, ) -> Self
Sets the value of document_processing_mode.
Example
ⓘ
use google_cloud_dialogflow_cx_v3::model::DocumentProcessingMode;
let x0 = DataStoreConnection::new().set_document_processing_mode(DocumentProcessingMode::Documents);
let x1 = DataStoreConnection::new().set_document_processing_mode(DocumentProcessingMode::Chunks);Trait Implementations
Sourceimpl Clone for DataStoreConnection
impl Clone for DataStoreConnection
Sourcefn clone(&self) -> DataStoreConnection
fn clone(&self) -> DataStoreConnection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataStoreConnection
impl Debug for DataStoreConnection
Sourceimpl Default for DataStoreConnection
impl Default for DataStoreConnection
Sourcefn default() -> DataStoreConnection
fn default() -> DataStoreConnection
Returns the “default value” for a type. Read more
Sourceimpl Message for DataStoreConnection
impl Message for DataStoreConnection
Sourceimpl PartialEq for DataStoreConnection
impl PartialEq for DataStoreConnection
Sourcefn eq(&self, other: &DataStoreConnection) -> bool
fn eq(&self, other: &DataStoreConnection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataStoreConnection