DataStoreConnectionSignals

Struct DataStoreConnectionSignals 

#[non_exhaustive]
pub struct DataStoreConnectionSignals { pub rewriter_model_call_signals: Option<RewriterModelCallSignals>, pub rewritten_query: String, pub search_snippets: Vec<SearchSnippet>, pub answer_generation_model_call_signals: Option<AnswerGenerationModelCallSignals>, pub answer: String, pub answer_parts: Vec<AnswerPart>, pub cited_snippets: Vec<CitedSnippet>, pub grounding_signals: Option<GroundingSignals>, pub safety_signals: Option<SafetySignals>, /* private fields */ }
Available on crate feature sessions only.
Data store connection feature output signals. Might be only partially field if processing stop before the final answer. Reasons for this can be, but are not limited to: empty UCS search results, positive RAI check outcome, grounding failure, …

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
rewriter_model_call_signals: Option<RewriterModelCallSignals>

Optional. Diagnostic info related to the rewriter model call.

rewritten_query: String

Optional. Rewritten string query used for search.

search_snippets: Vec<SearchSnippet>

Optional. Search snippets included in the answer generation prompt.

answer_generation_model_call_signals: Option<AnswerGenerationModelCallSignals>

Optional. Diagnostic info related to the answer generation model call.

answer: String

Optional. The final compiled answer.

answer_parts: Vec<AnswerPart>

Optional. Answer parts with relevant citations. Concatenation of texts should add up the answer (not counting whitespaces).

cited_snippets: Vec<CitedSnippet>

Optional. Snippets cited by the answer generation model from the most to least relevant.

grounding_signals: Option<GroundingSignals>

Optional. Grounding signals.

safety_signals: Option<SafetySignals>

Optional. Safety check result.

Implementations

Source

impl DataStoreConnectionSignals

pub fn new() -> Self

Creates a new default instance.

pub fn set_rewriter_model_call_signals<T>(self, v: T) -> Self

Sets the value of rewriter_model_call_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::RewriterModelCallSignals;
let x = DataStoreConnectionSignals::new().set_rewriter_model_call_signals(RewriterModelCallSignals::default()/* use setters */);
pub fn set_or_clear_rewriter_model_call_signals<T>(self, v: Option<T>) -> Self

Sets or clears the value of rewriter_model_call_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::RewriterModelCallSignals;
let x = DataStoreConnectionSignals::new().set_or_clear_rewriter_model_call_signals(Some(RewriterModelCallSignals::default()/* use setters */));
let x = DataStoreConnectionSignals::new().set_or_clear_rewriter_model_call_signals(None::<RewriterModelCallSignals>);
pub fn set_rewritten_query<T: Into<String>>(self, v: T) -> Self

Sets the value of rewritten_query.

Example
let x = DataStoreConnectionSignals::new().set_rewritten_query("example");
pub fn set_search_snippets<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<SearchSnippet>,

Sets the value of search_snippets.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::SearchSnippet;
let x = DataStoreConnectionSignals::new()
    .set_search_snippets([
        SearchSnippet::default()/* use setters */,
        SearchSnippet::default()/* use (different) setters */,
    ]);
pub fn set_answer_generation_model_call_signals<T>(self, v: T) -> Self

Sets the value of answer_generation_model_call_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::AnswerGenerationModelCallSignals;
let x = DataStoreConnectionSignals::new().set_answer_generation_model_call_signals(AnswerGenerationModelCallSignals::default()/* use setters */);
pub fn set_or_clear_answer_generation_model_call_signals<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of answer_generation_model_call_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::AnswerGenerationModelCallSignals;
let x = DataStoreConnectionSignals::new().set_or_clear_answer_generation_model_call_signals(Some(AnswerGenerationModelCallSignals::default()/* use setters */));
let x = DataStoreConnectionSignals::new().set_or_clear_answer_generation_model_call_signals(None::<AnswerGenerationModelCallSignals>);
pub fn set_answer<T: Into<String>>(self, v: T) -> Self

Sets the value of answer.

Example
let x = DataStoreConnectionSignals::new().set_answer("example");
pub fn set_answer_parts<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<AnswerPart>,

Sets the value of answer_parts.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::AnswerPart;
let x = DataStoreConnectionSignals::new()
    .set_answer_parts([
        AnswerPart::default()/* use setters */,
        AnswerPart::default()/* use (different) setters */,
    ]);
pub fn set_cited_snippets<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<CitedSnippet>,

Sets the value of cited_snippets.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::CitedSnippet;
let x = DataStoreConnectionSignals::new()
    .set_cited_snippets([
        CitedSnippet::default()/* use setters */,
        CitedSnippet::default()/* use (different) setters */,
    ]);
pub fn set_grounding_signals<T>(self, v: T) -> Self

Sets the value of grounding_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::GroundingSignals;
let x = DataStoreConnectionSignals::new().set_grounding_signals(GroundingSignals::default()/* use setters */);
pub fn set_or_clear_grounding_signals<T>(self, v: Option<T>) -> Self

Sets or clears the value of grounding_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::GroundingSignals;
let x = DataStoreConnectionSignals::new().set_or_clear_grounding_signals(Some(GroundingSignals::default()/* use setters */));
let x = DataStoreConnectionSignals::new().set_or_clear_grounding_signals(None::<GroundingSignals>);
pub fn set_safety_signals<T>(self, v: T) -> Self
where T: Into<SafetySignals>,

Sets the value of safety_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::SafetySignals;
let x = DataStoreConnectionSignals::new().set_safety_signals(SafetySignals::default()/* use setters */);
pub fn set_or_clear_safety_signals<T>(self, v: Option<T>) -> Self
where T: Into<SafetySignals>,

Sets or clears the value of safety_signals.

Example
use google_cloud_dialogflow_cx_v3::model::data_store_connection_signals::SafetySignals;
let x = DataStoreConnectionSignals::new().set_or_clear_safety_signals(Some(SafetySignals::default()/* use setters */));
let x = DataStoreConnectionSignals::new().set_or_clear_safety_signals(None::<SafetySignals>);