QueryInput

Struct QueryInput 

#[non_exhaustive]
pub struct QueryInput { pub language_code: String, pub input: Option<Input>, /* private fields */ }
Available on crate features sessions or test-cases only.
Represents the query input. It can contain one of:

  1. A conversational query in the form of text.

  2. An intent query that specifies which intent to trigger.

  3. Natural language speech audio to be processed.

  4. An event to be triggered.

  5. DTMF digits to invoke an intent and fill in parameter value.

  6. The results of a tool executed by the client.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
language_code: String

Required. The language of the input. See Language Support for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.

input: Option<Input>

Required. The input specification.

Implementations

Source

impl QueryInput

pub fn new() -> Self

Creates a new default instance.

pub fn set_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of language_code.

Example
let x = QueryInput::new().set_language_code("example");
pub fn set_input<T: Into<Option<Input>>>(self, v: T) -> Self

Sets the value of input.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::TextInput;
let x = QueryInput::new().set_input(Some(
    google_cloud_dialogflow_cx_v3::model::query_input::Input::Text(TextInput::default().into())));
pub fn text(&self) -> Option<&Box<TextInput>>

The value of input if it holds a Text, None if the field is not set or holds a different branch.

pub fn set_text<T: Into<Box<TextInput>>>(self, v: T) -> Self

Sets the value of input to hold a Text.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::TextInput;
let x = QueryInput::new().set_text(TextInput::default()/* use setters */);
assert!(x.text().is_some());
assert!(x.intent().is_none());
assert!(x.audio().is_none());
assert!(x.event().is_none());
assert!(x.dtmf().is_none());
assert!(x.tool_call_result().is_none());
pub fn intent(&self) -> Option<&Box<IntentInput>>

The value of input if it holds a Intent, None if the field is not set or holds a different branch.

pub fn set_intent<T: Into<Box<IntentInput>>>(self, v: T) -> Self

Sets the value of input to hold a Intent.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::IntentInput;
let x = QueryInput::new().set_intent(IntentInput::default()/* use setters */);
assert!(x.intent().is_some());
assert!(x.text().is_none());
assert!(x.audio().is_none());
assert!(x.event().is_none());
assert!(x.dtmf().is_none());
assert!(x.tool_call_result().is_none());
pub fn audio(&self) -> Option<&Box<AudioInput>>

The value of input if it holds a Audio, None if the field is not set or holds a different branch.

pub fn set_audio<T: Into<Box<AudioInput>>>(self, v: T) -> Self

Sets the value of input to hold a Audio.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::AudioInput;
let x = QueryInput::new().set_audio(AudioInput::default()/* use setters */);
assert!(x.audio().is_some());
assert!(x.text().is_none());
assert!(x.intent().is_none());
assert!(x.event().is_none());
assert!(x.dtmf().is_none());
assert!(x.tool_call_result().is_none());
pub fn event(&self) -> Option<&Box<EventInput>>

The value of input if it holds a Event, None if the field is not set or holds a different branch.

pub fn set_event<T: Into<Box<EventInput>>>(self, v: T) -> Self

Sets the value of input to hold a Event.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::EventInput;
let x = QueryInput::new().set_event(EventInput::default()/* use setters */);
assert!(x.event().is_some());
assert!(x.text().is_none());
assert!(x.intent().is_none());
assert!(x.audio().is_none());
assert!(x.dtmf().is_none());
assert!(x.tool_call_result().is_none());
pub fn dtmf(&self) -> Option<&Box<DtmfInput>>

The value of input if it holds a Dtmf, None if the field is not set or holds a different branch.

pub fn set_dtmf<T: Into<Box<DtmfInput>>>(self, v: T) -> Self

Sets the value of input to hold a Dtmf.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::DtmfInput;
let x = QueryInput::new().set_dtmf(DtmfInput::default()/* use setters */);
assert!(x.dtmf().is_some());
assert!(x.text().is_none());
assert!(x.intent().is_none());
assert!(x.audio().is_none());
assert!(x.event().is_none());
assert!(x.tool_call_result().is_none());
pub fn tool_call_result(&self) -> Option<&Box<ToolCallResult>>

The value of input if it holds a ToolCallResult, None if the field is not set or holds a different branch.

pub fn set_tool_call_result<T: Into<Box<ToolCallResult>>>(self, v: T) -> Self

Sets the value of input to hold a ToolCallResult.

Note that all the setters affecting input are mutually exclusive.

Example
use google_cloud_dialogflow_cx_v3::model::ToolCallResult;
let x = QueryInput::new().set_tool_call_result(ToolCallResult::default()/* use setters */);
assert!(x.tool_call_result().is_some());
assert!(x.text().is_none());
assert!(x.intent().is_none());
assert!(x.audio().is_none());
assert!(x.event().is_none());
assert!(x.dtmf().is_none());