#[non_exhaustive]pub struct UpdateExampleRequest {
pub example: Option<Example>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Available on crate feature
examples only.Expand description
The request message for Examples.UpdateExample.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.example: Option<Example>Required. The example to update.
update_mask: Option<FieldMask>Optional. The mask to control which fields get updated. If the mask is not present, all fields will be updated.
Implementations
Sourceimpl UpdateExampleRequest
impl UpdateExampleRequest
Sourcepub fn set_example<T>(self, v: T) -> Self
pub fn set_example<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_example<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_example<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateExampleRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateExampleRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateExampleRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateExampleRequest
impl Clone for UpdateExampleRequest
Sourcefn clone(&self) -> UpdateExampleRequest
fn clone(&self) -> UpdateExampleRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateExampleRequest
impl Debug for UpdateExampleRequest
Sourceimpl Default for UpdateExampleRequest
impl Default for UpdateExampleRequest
Sourcefn default() -> UpdateExampleRequest
fn default() -> UpdateExampleRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateExampleRequest
impl Message for UpdateExampleRequest
Sourceimpl PartialEq for UpdateExampleRequest
impl PartialEq for UpdateExampleRequest
Sourcefn eq(&self, other: &UpdateExampleRequest) -> bool
fn eq(&self, other: &UpdateExampleRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateExampleRequest