#[non_exhaustive]pub enum Query {
Text(String),
TriggerIntent(String),
Transcript(String),
TriggerEvent(String),
DtmfDigits(String),
}Available on crate features
agents and changelogs and deployments and entity-types and environments and examples and experiments and flows and generators and intents and pages and playbooks and security-settings-service and session-entity-types and sessions and test-cases and tools and transition-route-groups and versions and webhooks only.Expand description
The original conversational query.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text(String)
If natural language text was provided as input, this field will contain a copy of the text.
TriggerIntent(String)
If an intent was provided as
input, this field will contain a copy of the intent identifier. Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/intents/<IntentID>.
Transcript(String)
If natural language speech audio was provided as input, this field will contain the transcript for the audio.
TriggerEvent(String)
If an event was provided as input, this field will contain the name of the event.
DtmfDigits(String)
If DTMF was provided as input, this field will contain the DTMF digits.