#[non_exhaustive]pub struct QueryParameters {Show 18 fields
pub time_zone: String,
pub geo_location: Option<LatLng>,
pub session_entity_types: Vec<SessionEntityType>,
pub payload: Option<Struct>,
pub parameters: Option<Struct>,
pub parameter_scope: String,
pub current_page: String,
pub disable_webhook: bool,
pub analyze_query_text_sentiment: bool,
pub webhook_headers: HashMap<String, String>,
pub flow_versions: Vec<String>,
pub current_playbook: String,
pub llm_model_settings: Option<LlmModelSettings>,
pub channel: String,
pub session_ttl: Option<Duration>,
pub end_user_metadata: Option<Struct>,
pub search_config: Option<SearchConfig>,
pub populate_data_store_connection_signals: bool,
/* private fields */
}sessions only.Expand description
Represents the parameters of a conversational query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_zone: StringThe time zone of this conversational query from the time zone database, e.g., America/New_York, Europe/Paris. If not provided, the time zone specified in the agent is used.
geo_location: Option<LatLng>The geo location of this conversational query.
session_entity_types: Vec<SessionEntityType>Additional session entity types to replace or extend developer entity types with. The entity synonyms apply to all languages and persist for the session of this query.
payload: Option<Struct>This field can be used to pass custom data into the webhook associated with the agent. Arbitrary JSON objects are supported. Some integrations that query a Dialogflow agent may provide additional information in the payload. In particular, for the Dialogflow Phone Gateway integration, this field has the form:
{
"telephony": {
"caller_id": "+18558363987"
}
}parameters: Option<Struct>Additional parameters to be put into session parameters. To remove a parameter from the session, clients should explicitly set the parameter value to null.
You can reference the session parameters in the agent with the following format: $session.params.parameter-id.
Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs:
- MapKey type: string
- MapKey value: parameter name
- MapValue type: If parameter’s entity type is a composite entity then use map, otherwise, depending on the parameter value type, it could be one of string, number, boolean, null, list or map.
- MapValue value: If parameter’s entity type is a composite entity then use map from composite entity property names to property values, otherwise, use parameter value.
parameter_scope: StringScope for the parameters. If not specified, parameters will be treated as session parameters. Parameters with custom scope will not be put into session parameters.
You can reference the parameters with custom scope in the agent with the following format: $parameter-scope.params.parameter-id.
current_page: StringThe unique identifier of the page to
override the current page in the session.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>/pages/<PageID>.
If current_page is specified, the previous state of the session will be
ignored by Dialogflow, including the previous
page and the previous session
parameters.
In most cases,
current_page
and parameters
should be configured together to direct a session to a specific state.
disable_webhook: boolWhether to disable webhook calls for this request.
analyze_query_text_sentiment: boolConfigures whether sentiment analysis should be performed. If not provided, sentiment analysis is not performed.
webhook_headers: HashMap<String, String>This field can be used to pass HTTP headers for a webhook call. These headers will be sent to webhook along with the headers that have been configured through Dialogflow web console. The headers defined within this field will overwrite the headers configured through Dialogflow console if there is a conflict. Header names are case-insensitive. Google’s specified headers are not allowed. Including: “Host”, “Content-Length”, “Connection”, “From”, “User-Agent”, “Accept-Encoding”, “If-Modified-Since”, “If-None-Match”, “X-Forwarded-For”, etc.
flow_versions: Vec<String>A list of flow versions to override for the request.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>/versions/<VersionID>.
If version 1 of flow X is included in this list, the traffic of flow X will go through version 1 regardless of the version configuration in the environment. Each flow can have at most one version specified in this list.
current_playbook: StringOptional. The unique identifier of the
playbook to start or continue the
session with. If current_playbook is specified, the previous state of the
session will be ignored by Dialogflow.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.
llm_model_settings: Option<LlmModelSettings>Optional. Use the specified LLM model settings for processing the request.
channel: StringThe channel which this query is for.
If specified, only the ResponseMessage associated with the channel will be returned. If no ResponseMessage is associated with the channel, it falls back to the ResponseMessage with unspecified channel.
If unspecified, the ResponseMessage with unspecified channel will be returned.
session_ttl: Option<Duration>Optional. Configure lifetime of the Dialogflow session. By default, a Dialogflow session remains active and its data is stored for 30 minutes after the last request is sent for the session. This value should be no longer than 1 day.
end_user_metadata: Option<Struct>Optional. Information about the end-user to improve the relevance and accuracy of generative answers.
This will be interpreted and used by a language model, so, for good results, the data should be self-descriptive, and in a simple structure.
Example:
{
"subscription plan": "Business Premium Plus",
"devices owned": [
{"model": "Google Pixel 7"},
{"model": "Google Pixel Tablet"}
]
}search_config: Option<SearchConfig>Optional. Search configuration for UCS search queries.
populate_data_store_connection_signals: boolOptional. If set to true and data stores are involved in serving the request then DetectIntentResponse.query_result.data_store_connection_signals will be filled with data that can help evaluations.
Implementations
Sourceimpl QueryParameters
impl QueryParameters
Sourcepub fn set_time_zone<T: Into<String>>(self, v: T) -> Self
pub fn set_time_zone<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_geo_location<T>(self, v: T) -> Self
pub fn set_geo_location<T>(self, v: T) -> Self
Sets the value of geo_location.
Example
use google_cloud_type::model::LatLng;
let x = QueryParameters::new().set_geo_location(LatLng::default()/* use setters */);Sourcepub fn set_or_clear_geo_location<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_geo_location<T>(self, v: Option<T>) -> Self
Sets or clears the value of geo_location.
Example
use google_cloud_type::model::LatLng;
let x = QueryParameters::new().set_or_clear_geo_location(Some(LatLng::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_geo_location(None::<LatLng>);Sourcepub fn set_session_entity_types<T, V>(self, v: T) -> Self
pub fn set_session_entity_types<T, V>(self, v: T) -> Self
Sets the value of session_entity_types.
Example
use google_cloud_dialogflow_cx_v3::model::SessionEntityType;
let x = QueryParameters::new()
.set_session_entity_types([
SessionEntityType::default()/* use setters */,
SessionEntityType::default()/* use (different) setters */,
]);Sourcepub fn set_payload<T>(self, v: T) -> Self
pub fn set_payload<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_payload<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_payload<T>(self, v: Option<T>) -> Self
Sourcepub fn set_parameters<T>(self, v: T) -> Self
pub fn set_parameters<T>(self, v: T) -> Self
Sets the value of parameters.
Example
use wkt::Struct;
let x = QueryParameters::new().set_parameters(Struct::default()/* use setters */);Sourcepub fn set_or_clear_parameters<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_parameters<T>(self, v: Option<T>) -> Self
Sets or clears the value of parameters.
Example
use wkt::Struct;
let x = QueryParameters::new().set_or_clear_parameters(Some(Struct::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_parameters(None::<Struct>);Sourcepub fn set_parameter_scope<T: Into<String>>(self, v: T) -> Self
pub fn set_parameter_scope<T: Into<String>>(self, v: T) -> Self
Sets the value of parameter_scope.
Example
let x = QueryParameters::new().set_parameter_scope("example");Sourcepub fn set_current_page<T: Into<String>>(self, v: T) -> Self
pub fn set_current_page<T: Into<String>>(self, v: T) -> Self
Sets the value of current_page.
Example
let x = QueryParameters::new().set_current_page(format!("projects/{project_id}/locations/{location_id}/agents/{agent_id}/flows/{flow_id}/pages/{page_id}"));Sourcepub fn set_disable_webhook<T: Into<bool>>(self, v: T) -> Self
pub fn set_disable_webhook<T: Into<bool>>(self, v: T) -> Self
Sets the value of disable_webhook.
Example
let x = QueryParameters::new().set_disable_webhook(true);Sourcepub fn set_analyze_query_text_sentiment<T: Into<bool>>(self, v: T) -> Self
pub fn set_analyze_query_text_sentiment<T: Into<bool>>(self, v: T) -> Self
Sets the value of analyze_query_text_sentiment.
Example
let x = QueryParameters::new().set_analyze_query_text_sentiment(true);Sourcepub fn set_webhook_headers<T, K, V>(self, v: T) -> Self
pub fn set_webhook_headers<T, K, V>(self, v: T) -> Self
Sets the value of webhook_headers.
Example
let x = QueryParameters::new().set_webhook_headers([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_flow_versions<T, V>(self, v: T) -> Self
pub fn set_flow_versions<T, V>(self, v: T) -> Self
Sets the value of flow_versions.
Example
let x = QueryParameters::new().set_flow_versions(["a", "b", "c"]);Sourcepub fn set_current_playbook<T: Into<String>>(self, v: T) -> Self
pub fn set_current_playbook<T: Into<String>>(self, v: T) -> Self
Sets the value of current_playbook.
Example
let x = QueryParameters::new().set_current_playbook(format!("projects/{project_id}/locations/{location_id}/agents/{agent_id}/playbooks/{playbook_id}"));Sourcepub fn set_llm_model_settings<T>(self, v: T) -> Selfwhere
T: Into<LlmModelSettings>,
pub fn set_llm_model_settings<T>(self, v: T) -> Selfwhere
T: Into<LlmModelSettings>,
Sets the value of llm_model_settings.
Example
use google_cloud_dialogflow_cx_v3::model::LlmModelSettings;
let x = QueryParameters::new().set_llm_model_settings(LlmModelSettings::default()/* use setters */);Sourcepub fn set_or_clear_llm_model_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LlmModelSettings>,
pub fn set_or_clear_llm_model_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LlmModelSettings>,
Sets or clears the value of llm_model_settings.
Example
use google_cloud_dialogflow_cx_v3::model::LlmModelSettings;
let x = QueryParameters::new().set_or_clear_llm_model_settings(Some(LlmModelSettings::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_llm_model_settings(None::<LlmModelSettings>);Sourcepub fn set_channel<T: Into<String>>(self, v: T) -> Self
pub fn set_channel<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_session_ttl<T>(self, v: T) -> Self
pub fn set_session_ttl<T>(self, v: T) -> Self
Sets the value of session_ttl.
Example
use wkt::Duration;
let x = QueryParameters::new().set_session_ttl(Duration::default()/* use setters */);Sourcepub fn set_or_clear_session_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_session_ttl<T>(self, v: Option<T>) -> Self
Sets or clears the value of session_ttl.
Example
use wkt::Duration;
let x = QueryParameters::new().set_or_clear_session_ttl(Some(Duration::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_session_ttl(None::<Duration>);Sourcepub fn set_end_user_metadata<T>(self, v: T) -> Self
pub fn set_end_user_metadata<T>(self, v: T) -> Self
Sets the value of end_user_metadata.
Example
use wkt::Struct;
let x = QueryParameters::new().set_end_user_metadata(Struct::default()/* use setters */);Sourcepub fn set_or_clear_end_user_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_user_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of end_user_metadata.
Example
use wkt::Struct;
let x = QueryParameters::new().set_or_clear_end_user_metadata(Some(Struct::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_end_user_metadata(None::<Struct>);Sourcepub fn set_search_config<T>(self, v: T) -> Selfwhere
T: Into<SearchConfig>,
pub fn set_search_config<T>(self, v: T) -> Selfwhere
T: Into<SearchConfig>,
Sets the value of search_config.
Example
use google_cloud_dialogflow_cx_v3::model::SearchConfig;
let x = QueryParameters::new().set_search_config(SearchConfig::default()/* use setters */);Sourcepub fn set_or_clear_search_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchConfig>,
pub fn set_or_clear_search_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchConfig>,
Sets or clears the value of search_config.
Example
use google_cloud_dialogflow_cx_v3::model::SearchConfig;
let x = QueryParameters::new().set_or_clear_search_config(Some(SearchConfig::default()/* use setters */));
let x = QueryParameters::new().set_or_clear_search_config(None::<SearchConfig>);Sourcepub fn set_populate_data_store_connection_signals<T: Into<bool>>(
self,
v: T,
) -> Self
👎Deprecated
pub fn set_populate_data_store_connection_signals<T: Into<bool>>( self, v: T, ) -> Self
Sets the value of populate_data_store_connection_signals.
Example
let x = QueryParameters::new().set_populate_data_store_connection_signals(true);Trait Implementations
Sourceimpl Clone for QueryParameters
impl Clone for QueryParameters
Sourcefn clone(&self) -> QueryParameters
fn clone(&self) -> QueryParameters
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for QueryParameters
impl Debug for QueryParameters
Sourceimpl Default for QueryParameters
impl Default for QueryParameters
Sourcefn default() -> QueryParameters
fn default() -> QueryParameters
Sourceimpl Message for QueryParameters
impl Message for QueryParameters
Sourceimpl PartialEq for QueryParameters
impl PartialEq for QueryParameters
Sourcefn eq(&self, other: &QueryParameters) -> bool
fn eq(&self, other: &QueryParameters) -> bool
self and other values to be equal, and is used by ==.